Method: Pokan::RequestHandler#push_message
- Defined in:
- lib/pokan/request_handler.rb
#push_message(keys) ⇒ Object
Get a pull message containing all status and keys based on the given keys following the structure: Given structure: [:key1, :key2, …]
67 68 69 |
# File 'lib/pokan/request_handler.rb', line 67 def (keys) { action: 'push', data: retrieve(keys), origin:"#{address}:#{port}" }.to_json end |